@@ -12,9 +12,9 @@ Control Things User Interface, aka ctui.py
 # FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 # details at <http://www.gnu.org/licenses/>.
 """
-from ctui.application import Ctui
 import ctui.types
+from ctui.application import Ctui
 
 __all__ = [
-    'Ctui',
-    ]
+    "Ctui",
+]
